@@ -1,9 +1,11 @@
 from concurrent.futures import ThreadPoolExecutor
+import os
 import time
 import unittest
 
 import pytest
 
+from prometheus_client import metrics
 from prometheus_client.core import (
     CollectorRegistry, Counter, CounterMetricFamily, Enum, Gauge,
     GaugeHistogramMetricFamily, GaugeMetricFamily, Histogram,
@@ -11,6 +13,7 @@ from prometheus_client.core import (
     StateSetMetricFamily, Summary, SummaryMetricFamily, UntypedMetricFamily,
 )
 from prometheus_client.decorator import getargspec
+from prometheus_client.metrics import _get_use_created
 
 
 def assert_not_observable(fn, *args, **kwargs):
@@ -40,6 +43,16 @@ class TestCounter(unittest.TestCase):
         self.counter.inc(7)
         self.assertEqual(8, self.registry.get_sample_value('c_total'))
 
+    def test_reset(self):
+        self.counter.inc()
+        self.assertNotEqual(0, self.registry.get_sample_value('c_total'))
+        created = self.registry.get_sample_value('c_created')
+        time.sleep(0.05)
+        self.counter.reset()        
+        self.assertEqual(0, self.registry.get_sample_value('c_total'))
+        created_after_reset = self.registry.get_sample_value('c_created')
+        self.assertLess(created, created_after_reset)       
+
     def test_repr(self):
         self.assertEqual(repr(self.counter), "prometheus_client.metrics.Counter(c)")
 
@@ -115,6 +128,32 @@ class TestCounter(unittest.TestCase):
         })
 
 
+class TestDisableCreated(unittest.TestCase):
+    def setUp(self):
+        self.registry = CollectorRegistry()
+        os.environ['PROMETHEUS_DISABLE_CREATED_SERIES'] = 'True'
+        metrics._use_created = _get_use_created()
+
+    def tearDown(self):
+        os.environ.pop('PROMETHEUS_DISABLE_CREATED_SERIES', None)
+        metrics._use_created = _get_use_created()
+
+    def test_counter(self):
+        counter = Counter('c_total', 'help', registry=self.registry)
+        counter.inc()
+        self.assertEqual(None, self.registry.get_sample_value('c_created'))
+
+    def test_histogram(self):
+        histogram = Histogram('h', 'help', registry=self.registry)
+        histogram.observe(3.2)
+        self.assertEqual(None, self.registry.get_sample_value('h_created'))
+
+    def test_summary(self):
+        summary = Summary('s', 'help', registry=self.registry)
+        summary.observe(8.2)
+        self.assertEqual(None, self.registry.get_sample_value('s_created'))
+
+
 class TestGauge(unittest.TestCase):
     def setUp(self):
         self.registry = CollectorRegistry()
